:orphan:

Stokes components
=================

We plan to implement the `~spectral_cube.StokesSpectralCube` class
and will update the documentation once this class is ready to use.

.. TODO: first we need to make sure the StokesSpectralCube class is working.